@@ -6,7 +6,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-08-25'; # DATE
 our $DIST = 'Sah-Schemas-JSON'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our $schema = [str => {
     summary => 'A string that contains valid JSON',
@@ -47,7 +47,7 @@ Sah::Schema::json_str - A string that contains valid JSON
 
 =head1 VERSION
 
-This document describes version 0.004 of Sah::Schema::json_str (from Perl distribution Sah-Schemas-JSON), released on 2022-08-25.
+This document describes version 0.005 of Sah::Schema::json_str (from Perl distribution Sah-Schemas-JSON), released on 2022-08-25.
 
 =head1 SYNOPSIS
 
@@ -85,12 +85,12 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "\"foo\"";
+ $data = 1;
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
  $data = "foo";
- my $errmsg = $validator->($data); # => "String is not a valid JSON: 'false' expected, at character offset 0 (before \"foo\") at (eval 2394) line 13.\n"
+ my $errmsg = $validator->($data); # => "String is not a valid JSON: 'false' expected, at character offset 0 (before \"foo\") at (eval 2459) line 13.\n"
 
 Often a schema has coercion rule or default value, so after validation the
 validated value is different. To return the validated (set-as-default, coerced,
@@ -100,12 +100,12 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "\"foo\"";
- my $res = $validator->($data); # => ["","\"foo\""]
+ $data = 1;
+ my $res = $validator->($data); # => ["",1]
  
  # a sample invalid data
  $data = "foo";
- my $res = $validator->($data); # => ["String is not a valid JSON: 'false' expected, at character offset 0 (before \"foo\") at (eval 2400) line 13.\n","foo"]
+ my $res = $validator->($data); # => ["String is not a valid JSON: 'false' expected, at character offset 0 (before \"foo\") at (eval 2465) line 13.\n","foo"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
